import openai
import typer
from rich import print

import whisper_cli.env as env
from whisper_cli.env import _read_user_config

app = typer.Typer(no_args_is_help=True)
app.add_typer(env.env_app)
app.add_typer(env.key_app)


def get_file_type(file_name: str) -> str:
    """Returns the file type of the file_name."""
    return file_name.split(".")[-1]


def _check_response_format(response_format: str | None):
    if response_format is None:
        return None
    elif response_format in ["json", "srt", "verbose_json", "vtt"]:
        return response_format
    else:
        raise ValueError("Response format not supported by OpenAI.")


def get_file_content(file_name: str) -> str:
    """Returns the content of the file_name."""

    if get_file_type(file_name) not in [
        "mp3",
        "mp4",
        "mpeg",
        "mpga",
        "m4a",
        "wav",
        "webm",
    ]:
        raise ValueError("File type not supported.")

    return open(file_name, "rb")


def get_api_key(env: str = "default") -> str:
    """Returns the API key for the current environment."""
    user_config = _read_user_config()
    for key, value in user_config.items():
        if "active" in value:
            return value["api_key"]

    raise ValueError(
        "No active environment found. Activate one using `whisper activate-env`."
    )


def show_result(result, response_format: str | None):
    """Show result."""
    if response_format is None:
        response_format = "json"

    if response_format == "json":
        print(result["text"])
    else:
        print(result)


@app.command()
def transcribe(
    file_name: str,
    model: str = "whisper-1",
    prompt: str | None = None,
    response_format: str | None = None,
    temperature: float = 0,
    language: str | None = None,
):
    """Transcribe audio file using whisper."""
    openai.api_key = get_api_key()

    transcript = openai.Audio.transcribe(
        model,
        get_file_content(file_name),
        prompt=prompt,
        response_format=_check_response_format(response_format),
        temperature=temperature,
        language=language,
    )

    # TODO: return based on response_format
    show_result(transcript, response_format)


@app.command()
def translate(
    file_name: str,
    model: str = "whisper-1",
    prompt: str | None = None,
    response_format: str | None = None,
    temperature: float = 0,
):
    """Translate audio file using whisper."""
    openai.api_key = get_api_key()

    translation = openai.Audio.translate(
        model,
        get_file_content(file_name),
        prompt=prompt,
        response_format=_check_response_format(response_format),
        temperature=temperature,
    )

    show_result(translation, response_format)


if __name__ == "__main__":
    app()



import os

import toml
import typer
from rich import print

# TODO: factor this further into token setting app?
env_app = typer.Typer(
    name="env", help="Set the current environment.", no_args_is_help=True
)
key_app = typer.Typer(name="key", help="Manage OpenAI API keys.", no_args_is_help=True)

user_config_path: str = os.environ.get("OPENAI_CONFIG_PATH") or os.path.expanduser(
    "~/.openai.toml"
)


def _read_user_config():
    if os.path.exists(user_config_path):
        with open(user_config_path) as f:
            return toml.load(f)
    else:
        return {}


def _write_user_config(user_config):
    with open(user_config_path, "w") as f:
        toml.dump(user_config, f)


def _store_user_config(new_settings, env="default"):
    user_config = _read_user_config()
    user_config.setdefault(env, {}).update(**new_settings)
    _write_user_config(user_config)


@key_app.command("set")
def set_key(api_key: str, env: str = "default"):
    """Save OpenAI key."""
    _store_user_config({"api_key": api_key}, env=env)


@env_app.command("activate")
def activate_env(env: str = "default"):
    """Activate environment."""
    config = _read_user_config()

    if env not in config:
        raise ValueError(
            f"Environment {env} not found. Create it using `whisper set-key`."
        )

    for key, value in config.items():
        if "active" in value:
            del config[key]["active"]
    config[env]["active"] = True
    _write_user_config(config)


@env_app.command("list")
def list_envs():
    """List all environments."""
    config = _read_user_config()

    # print config.keys each on a new line
    print("[bold]Environments[/bold]")
    for key in config.keys():
        if "active" in config[key]:
            print(f" * [bold red]\[active][/bold red] {key}")
        else:
            print(f" * {key}")



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['whisper_cli']

package_data = \
{'': ['*']}

install_requires = \
['openai>=0.27.0,<0.28.0', 'toml>=0.10.2,<0.11.0', 'typer[all]>=0.7.0,<0.8.0']

entry_points = \
{'console_scripts': ['whisper = whisper_cli.main:app']}

setup_kwargs = {
    'name': 'whisper-cli',
    'version': '0.0.4',
    'description': "A command-line interface for transcribing and translating audio using OpenAI's Whisper API",
    'long_description': "# Whisper CLI\nWhisper CLI is a command-line interface for transcribing and translating audio using OpenAI's Whisper API. It also allows you to manage multiple OpenAI API keys as separate environments.\n\nTo install Whisper CLI, simply run:\n\n```sh\npip install whisper-cli\n```\n\n## Setup\nTo get started with Whisper CLI, you'll need to set your OpenAI API key. You can do this using the following command:\n\n```sh\nwhisper key set <openai_api_key>\n```\n\nThis will set the API key for the default environment. If you want to use a different API key, you can set up an alternative environment by running:\n\n```sh\nwhisper key set <openai_api_key> --env <env_name>\n```\n\nTo activate an alternative environment, run:\n\n```sh\nwhisper env activate <env_name>\n```\n\n## Usage\n\nWhisper CLI supports two main functionalities: translation and transcription.\n\n### Translation\nTo translate an audio file, simply run:\n\n```sh\nwhisper translate <file_name>\n```\n\n### Transcription\nTo transcribe an audio file, run:\n\n```sh\nwhisper transcribe <file_name>\n```\n\n## Development\nIf you'd like to contribute to Whisper CLI, you'll need to set up a development environment with Python 3.10.9.\n\n```sh\npython=3.10.9\n```\n\nHappy transcribing and translating with Whisper CLI.\n",
    'author': 'Vatsal',
    'author_email': 'vatsalaggarwal@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
